Colour Appearance Models
========================

ATD (1995)
----------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_ATD95
    CAM_Specification_ATD95

CIECAM02
--------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_CIECAM02
    CIECAM02_to_XYZ
    CAM_Specification_CIECAM02
    VIEWING_CONDITIONS_CIECAM02

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    CAM_KWARGS_CIECAM02_sRGB
    InductionFactors_CIECAM02

CIECAM16
--------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_CIECAM16
    CIECAM16_to_XYZ
    CAM_Specification_CIECAM16
    VIEWING_CONDITIONS_CIECAM16

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    InductionFactors_CIECAM16

CAM16
-----

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_CAM16
    CAM16_to_XYZ
    CAM_Specification_CAM16
    VIEWING_CONDITIONS_CAM16

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    InductionFactors_CAM16

Hellwig and Fairchild (2022) Colour Appearance Model
----------------------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Hellwig2022
    Hellwig2022_to_XYZ
    CAM_Specification_Hellwig2022
    VIEWING_CONDITIONS_HELLWIG2022

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    InductionFactors_Hellwig2022

Hunt
----

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Hunt
    CAM_Specification_Hunt
    VIEWING_CONDITIONS_HUNT

Kim, Weyrich and Kautz (2009)
-----------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Kim2009
    Kim2009_to_XYZ
    CAM_Specification_Kim2009
    MEDIA_PARAMETERS_KIM2009
    VIEWING_CONDITIONS_KIM2009

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    InductionFactors_Kim2009
    MediaParameters_Kim2009

:math:`LLAB(l:c)`
-----------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_LLAB
    CAM_Specification_LLAB
    VIEWING_CONDITIONS_LLAB

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    InductionFactors_LLAB

Nayatani (1995)
---------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_Nayatani95
    CAM_Specification_Nayatani95

RLAB
----

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_RLAB
    CAM_Specification_RLAB
    VIEWING_CONDITIONS_RLAB

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    D_FACTOR_RLAB

ZCAM
----

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    XYZ_to_ZCAM
    ZCAM_to_XYZ
    CAM_Specification_ZCAM
    VIEWING_CONDITIONS_ZCAM

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    InductionFactors_ZCAM

Helmholtz-Kohlrausch Effect Estimation
--------------------------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    HKE_NAYATANI1997_METHODS
    HelmholtzKohlrausch_effect_object_Nayatani1997
    HelmholtzKohlrausch_effect_luminous_Nayatani1997

**Ancillary Objects**

``colour.appearance``

.. currentmodule:: colour.appearance

.. autosummary::
    :toctree: generated/

    coefficient_q_Nayatani1997
    coefficient_K_Br_Nayatani1997
